.. user_config documentation master file, created by
   sphinx-quickstart on Sat Feb 11 15:39:42 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to user_config's documentation!
=======================================
manage user configuration for python projects

Contents:

.. toctree::
   :maxdepth: 2

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: ../../README.rst
